@@ -63,14 +63,14 @@ class IconButton(ttk.Frame):
 
     def bind_widgets(self):
         for widget in (self, self.button_label):
-            widget.bind("<Button-1>", self._on_click)
-            widget.bind("<Enter>", self._enter_button)
-            widget.bind("<Leave>", lambda e: self.config(relief="raised"))
+            widget.bind('<Button-1>', self._on_click)
+            widget.bind('<Enter>', self._enter_button)
+            widget.bind('<Leave>', lambda e: self.config(relief='raised'))
 
     def _enter_button(self, event) -> None:
         if self._state == tk.DISABLED:
             return
-        self.config(relief="sunken")
+        self.config(relief='sunken')
         event.widget.winfo_toplevel().config(cursor=HAND)
 
     def _on_click(self, *args):
@@ -122,8 +122,11 @@ class ButtonFrame(ttk.Frame):
         }
 
     def icon_button(
-            self, id: str, dimmable: bool = False, command=None) -> IconButton:
-        button = self.icon_buttons[id]
+            self,
+            id_: str,
+            dimmable: bool = False,
+            command: object = None) -> IconButton:
+        button = self.icon_buttons[id_]
         button.dimmable = dimmable
         button.command = command
         return button
@@ -242,6 +245,7 @@ icon_buttons = {
     'run': (txt.RUN, 'start'),
     'save': (txt.SAVE, 'save'),
     'script': (txt.SCRIPT, 'script'),
+    'search': (txt.SEARCH, 'search'),
     'send': (txt.SEND, 'send'),
     'start': (txt.START, 'start'),
     'update': (txt.UPDATE, 'update'),
@@ -266,5 +270,5 @@ def list_icon_buttons() -> None:
 
     for name, button in icon_buttons.items():
         print(f'{name:<{name_length}} '
-               f'{button[0]:<{text_length}} '
-               f'{button[1]:<{icon_length}}')
+              f'{button[0]:<{text_length}} '
+              f'{button[1]:<{icon_length}}')
