@@ -49,6 +49,11 @@ TXT_FILE_TYPES = (
     ('All files', '*.*')
 )
 
+XML_FILE_TYPES = (
+    ('xml files', '*.xml'),
+    ('All files', '*.*')
+)
+
 
 class Pad():
     W = (0, PAD)
